package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DataUtils;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.system.mapper.WzzryMapper;
import com.ruoyi.system.domain.Wzzry;
import com.ruoyi.system.service.IWzzryService;

/**
 * 危重症人员Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-02
 */
@Service
public class WzzryServiceImpl implements IWzzryService 
{
    @Autowired
    private WzzryMapper wzzryMapper;

    /**
     * 查询危重症人员
     * 
     * @param id 危重症人员主键
     * @return 危重症人员
     */
    @Override
    public Wzzry selectWzzryById(Long id)
    {
        return wzzryMapper.selectWzzryById(id);
    }

    /**
     * 查询危重症人员列表
     * 
     * @param wzzry 危重症人员
     * @return 危重症人员
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<Wzzry> selectWzzryList(Wzzry wzzry)
    {
        return wzzryMapper.selectWzzryList(wzzry);
    }

    /**
     * 新增危重症人员
     * 
     * @param wzzry 危重症人员
     * @return 结果
     */
    @Override
    public int insertWzzry(Wzzry wzzry)
    {
        String createBy = DataUtils.getValue("1", wzzry.getStreet(), wzzry.getCommittee());
        if (createBy.equals("null"))
            throw new ServiceException("所选居住地、街道、社区不存在");
        List<Wzzry> list = wzzryMapper.selectWzzryByCard(wzzry.getCardNo());
        if (!list.isEmpty()){
            wzzry.setId(list.get(0).getId());
            wzzry.setCreateBy(createBy);
            return wzzryMapper.updateWzzry(wzzry);
        }
        wzzry.setCreateBy(createBy);
        wzzry.setCreateTime(DateUtils.getNowDate());
        return wzzryMapper.insertWzzry(wzzry);
    }

    /**
     * 修改危重症人员
     * 
     * @param wzzry 危重症人员
     * @return 结果
     */
    @Override
    public int updateWzzry(Wzzry wzzry)
    {
        String createBy = DataUtils.getValue("1", wzzry.getStreet(), wzzry.getCommittee());
        if (createBy.equals("null"))
            throw new ServiceException("所选居住地、街道、社区不存在");
        wzzry.setCreateBy(createBy);
        wzzry.setUpdateTime(DateUtils.getNowDate());
        return wzzryMapper.updateWzzry(wzzry);
    }

    /**
     * 批量删除危重症人员
     * 
     * @param ids 需要删除的危重症人员主键
     * @return 结果
     */
    @Override
    public int deleteWzzryByIds(Long[] ids)
    {
        return wzzryMapper.deleteWzzryByIds(ids);
    }

    /**
     * 删除危重症人员信息
     * 
     * @param id 危重症人员主键
     * @return 结果
     */
    @Override
    public int deleteWzzryById(Long id)
    {
        return wzzryMapper.deleteWzzryById(id);
    }
}
